
======================================================
How To Think Like a Computer Scientist C++ Edition
======================================================

.. Here is were you specify the content and order of your new book.

.. Each section heading (e.g. "SECTION 1: A Random Section") will be
   a heading in the table of contents. Source files that should be
   generated and included in that section should be placed on individual
   lines, with one line separating the first source filename and the
   :maxdepth: line.

.. Sources can also be included from subfolders of this directory.
   (e.g. "DataStructures/queues.rst").

Assignments
:::::::::::::::::

.. raw:: html

   <ul>
   <li><a href="/runestone/assignments/chooseAssignment.html">Assignments</a></li>
   </ul>

Table of Contents
:::::::::::::::::

.. toctree::
   :numbered:
   :maxdepth: 3

   Chapter1/toctree.rst
   Chapter2/toctree.rst
   Chapter3/toctree.rst
   Chapter4/toctree.rst
   Chapter5/toctree.rst
   Chapter6/toctree.rst
   Chapter7/toctree.rst
   Chapter8/toctree.rst
   Chapter9/toctree.rst
   Chapter10/toctree.rst
   Chapter11/toctree.rst
   Chapter12/toctree.rst
   Chapter13/toctree.rst
   Chapter14/toctree.rst
   Chapter15/toctree.rst

Acknowledgements
::::::::::::::::

.. toctree::
   :caption: Acknowledgements
   :maxdepth: 1

   ack/copyright.rst
   ack/contrib.rst
